********************
Module Documentation
********************

Detailed module and class documentation for every module in the
``ut-arr`` package.

.. toctree::
   :maxdepth: 2

   modules/arr
   modules/ao2a
   modules/aoa
   modules/aod
   modules/aoo
   modules/aos
